@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 
        @precisions normal z -> s d c
 */
@@ -26,6 +26,7 @@ extern "C" {
 #define blasf77_izamax     FORTRAN_NAME( izamax, IZAMAX )
 #define blasf77_zaxpy      FORTRAN_NAME( zaxpy,  ZAXPY  )
 #define blasf77_zcopy      FORTRAN_NAME( zcopy,  ZCOPY  )
+#define blasf77_zgbmv      FORTRAN_NAME( zgbmv,  ZGBMV  )
 #define blasf77_zgemm      FORTRAN_NAME( zgemm,  ZGEMM  )
 #define blasf77_zgemv      FORTRAN_NAME( zgemv,  ZGEMV  )
 #define blasf77_zgerc      FORTRAN_NAME( zgerc,  ZGERC  )
@@ -60,12 +61,14 @@ extern "C" {
 
 #define lapackf77_dbdsdc   FORTRAN_NAME( dbdsdc, DBDSDC )
 #define lapackf77_zbdsqr   FORTRAN_NAME( zbdsqr, ZBDSQR )
+#define lapackf77_zgbtrf   FORTRAN_NAME( zgbtrf, ZGBTRF )
 #define lapackf77_zgebak   FORTRAN_NAME( zgebak, ZGEBAK )
 #define lapackf77_zgebal   FORTRAN_NAME( zgebal, ZGEBAL )
 #define lapackf77_zgebd2   FORTRAN_NAME( zgebd2, ZGEBD2 )
 #define lapackf77_zgebrd   FORTRAN_NAME( zgebrd, ZGEBRD )
 #define lapackf77_zgbbrd   FORTRAN_NAME( zgbbrd, ZGBBRD )
 #define lapackf77_zgbsv    FORTRAN_NAME( zgbsv,  ZGBSV  )
+#define lapackf77_zgbtrs   FORTRAN_NAME( zgbtrs, ZGBTRS )
 #define lapackf77_zgeev    FORTRAN_NAME( zgeev,  ZGEEV  )
 #define lapackf77_zgehd2   FORTRAN_NAME( zgehd2, ZGEHD2 )
 #define lapackf77_zgehrd   FORTRAN_NAME( zgehrd, ZGEHRD )
@@ -105,6 +108,7 @@ extern "C" {
 #define lapackf77_zlacrm   FORTRAN_NAME( zlacrm, ZLACRM )
 #define lapackf77_zladiv   FORTRAN_NAME( zladiv, ZLADIV )
 #define lapackf77_zlahef   FORTRAN_NAME( zlahef, ZLAHEF )
+#define lapackf77_zlangb   FORTRAN_NAME( zlangb, ZLANGB )
 #define lapackf77_zlange   FORTRAN_NAME( zlange, ZLANGE )
 #define lapackf77_zlanhe   FORTRAN_NAME( zlanhe, ZLANHE )
 #define lapackf77_zlanht   FORTRAN_NAME( zlanht, ZLANHT )
@@ -190,6 +194,15 @@ void blasf77_zcopy(  const magma_int_t *n,
                      const magmaDoubleComplex *x, const magma_int_t *incx,
                            magmaDoubleComplex *y, const magma_int_t *incy );
 
+void blasf77_zgbmv(  const char *transa,
+                     const magma_int_t *m,  const magma_int_t *n,
+                     const magma_int_t *kl, const magma_int_t *ku,
+                     const magmaDoubleComplex *alpha,
+                     const magmaDoubleComplex *A, const magma_int_t *lda,
+                     const magmaDoubleComplex *x, const magma_int_t *incx,
+                     const magmaDoubleComplex *beta,
+                           magmaDoubleComplex *y, const magma_int_t *incy );
+
 void blasf77_zgemm(  const char *transa, const char *transb,
                      const magma_int_t *m, const magma_int_t *n, const magma_int_t *k,
                      const magmaDoubleComplex *alpha,
@@ -381,6 +394,12 @@ void   lapackf77_zbdsqr( const char *uplo,
                          double *work,
                          magma_int_t *info );
 
+void   lapackf77_zgbtrf( const magma_int_t  *m,  const magma_int_t *n,
+                         const magma_int_t  *kl, const magma_int_t *ku,
+                         magmaDoubleComplex *AB, const magma_int_t *ldab,
+                         magma_int_t *ipiv,
+                         magma_int_t *info );
+
 void   lapackf77_zgebak( const char *job, const char *side,
                          const magma_int_t *n,
                          const magma_int_t *ilo, const magma_int_t *ihi,
@@ -433,6 +452,15 @@ void   lapackf77_zgbsv( const magma_int_t *n,
                         magmaDoubleComplex *B, const magma_int_t *ldb,
                         magma_int_t *info );
 
+void   lapackf77_zgbtrs( const char *trans,
+                         const magma_int_t *n,
+                         const magma_int_t *kl, const magma_int_t *ku,
+                         const magma_int_t *nrhs,
+                         magmaDoubleComplex *ab, const magma_int_t *ldab,
+                         magma_int_t *ipiv,
+                         magmaDoubleComplex *B, const magma_int_t *ldb,
+                         magma_int_t *info );
+
 void   lapackf77_zgeev(  const char *jobvl, const char *jobvr,
                          const magma_int_t *n,
                          magmaDoubleComplex *A,    const magma_int_t *lda,
@@ -757,6 +785,11 @@ void   lapackf77_zlahef( const char *uplo,
                          magmaDoubleComplex *work, const magma_int_t *ldwork,
                          magma_int_t *info );
 
+double lapackf77_zlangb( const char *norm,
+                         const magma_int_t *n, const magma_int_t *kl, const magma_int_t *ku,
+                         const magmaDoubleComplex *AB, const magma_int_t *ldab,
+                         double *work );
+
 double lapackf77_zlange( const char *norm,
                          const magma_int_t *m, const magma_int_t *n,
                          const magmaDoubleComplex *A, const magma_int_t *lda,
