@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 */
 
 #ifndef MAGMASPARSE_TYPES_H
@@ -20,33 +20,6 @@
 #include <omp.h>
 #endif
 
-// includes CUDA
-#include <cusparse_v2.h>
-
-/* (author: Cade Brown <cbrow216@vols.utk.edu>
- *
- * There have been changes to cuSPARSE in 10.2, specifically many removed hybrid formatting/partitioning, some
- *   solvers, solve analysis, and sparse BLAS (doti, srmm, ...). So, those must be fixed in the cuSPARSE version.
- *
- * As a result, these functionalities are not even included as deprecated features in hipSPARSE, they are excluded entirely.
- *
- * In the future, `MAGMA_USE_SOLVEANALYSIS` and similar switches should default to 'off', once the cuSPARSE backend is fixed
- *
- *
- */
-
-// if defined, use the cusparseSolveAnalysisInfo_t structures & functionality
-//#define MAGMA_USE_SOLVEANALYSIS
-
-#if defined(MAGMA_HAVE_CUDA)
-// for now, enable, but this has been deprecated
-// eventually this should be disabled by default
-#define MAGMA_USE_SOLVEANALYSIS
-#elif defined(MAGMA_HAVE_HIP)
-
-#define MAGMA_USE_SOLVEANALYSIS
-#endif
-
 /* Currently unsupported hipsparse functions
  *
  * (these should be added in ROCm 3.5, or otherwise pretty soon)
@@ -419,63 +392,7 @@ extern "C"
     typedef magma_c_matrix magma_c_vector;
     typedef magma_z_matrix magma_z_vector;
 
-    /*
-typedef struct magma_z_vector
-{
-    magma_location_t   memory_location;         // CPU or DEV
-    magma_int_t        num_rows;                // number of rows
-    magma_int_t        num_cols;                // number of columns (in case of a block of vectors)
-    magma_int_t        nnz;                     // opt: number of nonzeros
-    union {
-        magmaDoubleComplex      *val;           // array containing values in CPU case
-        magmaDoubleComplex_ptr  dval;           // array containing values in DEV case
-    };
-    magma_order_t      major;                   // storage type:Row/Column-Major
-} magma_z_vector;
-
-typedef struct magma_c_vector
-{
-    magma_location_t   memory_location;         // CPU or DEV
-    magma_int_t        num_rows;                // number of rows
-    magma_int_t        num_cols;                // number of columns (in case of a block of vectors)
-    magma_int_t        nnz;                     // opt: number of nonzeros
-    union {
-        magmaFloatComplex       *val;           // array containing values in CPU case
-        magmaFloatComplex_ptr   dval;           // array containing values in DEV case
-    };
-    magma_order_t      major;                   // storage type:Row/Column-Major
-} magma_c_vector;
-
-
-typedef struct magma_d_vector
-{
-    magma_location_t   memory_location;         // CPU or DEV
-    magma_int_t        num_rows;                // number of rows
-    magma_int_t        num_cols;                // number of columns (in case of a block of vectors)
-    magma_int_t        nnz;                     // opt: number of nonzeros
-    union {
-        double                  *val;           // array containing values in CPU case
-        magmaDouble_ptr         dval;           // array containing values in DEV case
-    };
-    magma_order_t      major;                   // storage type:Row/Column-Major
-} magma_d_vector;
-
-
-typedef struct magma_s_vector
-{
-    magma_location_t   memory_location;         // CPU or DEV
-    magma_int_t        num_rows;                // number of rows
-    magma_int_t        num_cols;                // number of columns (in case of a block of vectors)
-    magma_int_t        nnz;                     // opt: number of nonzeros
-    union {
-        float                   *val;           // array containing values in CPU case
-        magmaFloat_ptr          dval;           // array containing values in DEV case
-    };
-    magma_order_t      major;                   // storage type:Row/Column-Major
-} magma_s_vector;
-*/
-
-    //*****************     solver parameters     ********************************//
+    /*****************     solver parameters     *******************************/
 
     typedef struct magma_z_solver_par
     {
@@ -632,21 +549,21 @@ typedef struct magma_s_vector
 #if CUDA_VERSION >= 12000
     #define csrsm2Info_t int
 #endif
-    
-#if CUDA_VERSION < 11031 || defined(MAGMA_HAVE_HIP)
+
 typedef struct magma_solve_info_t
 {
+    #if CUDA_VERSION < 11031 || defined(MAGMA_HAVE_HIP)
     csrsm2Info_t descr{};
-    void *buffer{};
-} magma_solve_info_t;
-//#define magma_ilu_info_t cusparseSolveAnalysisInfo_t
-#define magma_ilu_info_t csrsm2Info_t
-#else
-typedef struct magma_solve_info_t
-{
+    #else
     cusparseSpSMDescr_t descr{};
+    #endif
     void *buffer{};
 } magma_solve_info_t;
+// Older CUDA: use cusparseSolveAnalysisInfo_t
+#if (defined(MAGMA_HAVE_CUDA) && CUDA_VERSION < 11000) 
+#define magma_ilu_info_t cusparseSolveAnalysisInfo_t
+// HIP and newer CUDA: use csrsm2Info_t
+#else
 #define magma_ilu_info_t csrsm2Info_t
 #endif
 
