@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 
        @author Hartwig Anzt
 
@@ -264,6 +264,7 @@ magma_zicisaisetup(
     // magma_z_mvisu( precond->UD, queue ); 
      
 cleanup:
+    magma_queue_sync( queue );
     magma_free( sizes_d );
     magma_free_cpu( sizes_h );
     magma_free( locations_d );
