@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 
        Originally translated from lapack dlaln2.f to dlaln2.c using f2c.
        Later cleaned up by hand, particularly to be thread-safe (no static variables).
