@@ -1,9 +1,9 @@
 /*
-   -- MAGMA (version 2.7.2) --
+   -- MAGMA (version 2.9.0) --
    Univ. of Tennessee, Knoxville
    Univ. of California, Berkeley
    Univ. of Colorado, Denver
-   @date August 2023
+   @date January 2025
 
    @author Azzam Haidar
    @author Adrien Remy
@@ -161,6 +161,7 @@ magma_zgetrf_recpanel_nopiv_batched(
         if (arginfo != 0) return arginfo;
     }
 
+    magma_queue_sync( queue );
     magma_free(dA_displ);
     return 0;
 }
