@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 
        @author Raffaele Solca
        @author Mark Gates
@@ -255,6 +255,7 @@ magma_zunmql2_gpu(
     }
 
 cleanup:
+    magma_queue_sync( queue );
     magma_queue_destroy( queue );
     magma_free( dwork );
 
