@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.7.2) --
+    -- MAGMA (version 2.9.0) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2023
+       @date January 2025
 
        @precisions normal z -> c d s
        @author Mark Gates
@@ -42,16 +42,15 @@ int main(int argc, char **argv)
     int status = 0;
     magma_int_t     *dinfo_magma;
     magma_int_t batchCount;
-    
+
     magma_opts opts( MagmaOptsBatched );
     opts.parse_opts( argc, argv );
-    
-    double tol = opts.tolerance * lapackf77_dlamch("E");
 
+    double tol = opts.tolerance * lapackf77_dlamch("E");
     batchCount = opts.batchcount;
     magma_int_t columns;
     nrhs = opts.nrhs;
-    
+
     printf("%% Batchcount   N  NRHS   CPU Gflop/s (sec)   GPU Gflop/s (sec)   ||B - AX|| / N*||A||*||X||\n");
     printf("%%==========================================================================================\n");
     for( int itest = 0; itest < opts.ntest; ++itest ) {
@@ -63,19 +62,19 @@ int main(int argc, char **argv)
             n2     = lda*N * batchCount;
             lddb   = ldda;
             gflops = ( FLOPS_ZGETRF( N, N ) + FLOPS_ZGETRS( N, nrhs ) ) / 1e9 * batchCount;
-            
+
             TESTING_CHECK( magma_zmalloc_cpu( &h_A, n2    ));
             TESTING_CHECK( magma_zmalloc_cpu( &h_B, ldb*nrhs*batchCount ));
             TESTING_CHECK( magma_zmalloc_cpu( &h_X, ldb*nrhs*batchCount ));
             TESTING_CHECK( magma_dmalloc_cpu( &work, N ));
             TESTING_CHECK( magma_imalloc_cpu( &ipiv, N ));
             TESTING_CHECK( magma_imalloc_cpu( &cpu_info, batchCount ));
-            
+
             TESTING_CHECK( magma_imalloc( &dinfo_magma, batchCount ));
-            
+
             TESTING_CHECK( magma_zmalloc( &d_A, ldda*N*batchCount    ));
             TESTING_CHECK( magma_zmalloc( &d_B, lddb*nrhs*batchCount ));
-            
+
             TESTING_CHECK( magma_malloc( (void**) &d_A_array, batchCount * sizeof(magmaDoubleComplex*) ));
             TESTING_CHECK( magma_malloc( (void**) &d_B_array, batchCount * sizeof(magmaDoubleComplex*) ));
 
@@ -84,6 +83,7 @@ int main(int argc, char **argv)
             sizeB = ldb*nrhs*batchCount;
             lapackf77_zlarnv( &ione, ISEED, &sizeA, h_A );
             lapackf77_zlarnv( &ione, ISEED, &sizeB, h_B );
+
             // make A diagonally dominant, to not need pivoting
             for( int s=0; s < batchCount; ++s ) {
                 for( int i=0; i < N; ++i ) {
@@ -95,15 +95,28 @@ int main(int argc, char **argv)
             columns = N * batchCount;
             magma_zsetmatrix( N, columns,    h_A, lda, d_A, ldda, opts.queue );
             magma_zsetmatrix( N, nrhs*batchCount, h_B, ldb, d_B, lddb, opts.queue );
-            
+
             /* ====================================================================
                Performs operation using MAGMA
                =================================================================== */
             magma_zset_pointer( d_A_array, d_A, ldda, 0, 0, ldda*N, batchCount, opts.queue );
             magma_zset_pointer( d_B_array, d_B, lddb, 0, 0, lddb*nrhs, batchCount, opts.queue );
-            
+
             gpu_time = magma_sync_wtime( opts.queue );
-            info = magma_zgesv_nopiv_batched( N, nrhs, d_A_array, ldda, d_B_array, lddb, dinfo_magma, batchCount, opts.queue );
+            if(opts.version == 1) {
+                info = magma_zgesv_nopiv_batched(
+                        N, nrhs,
+                        d_A_array, ldda,
+                        d_B_array, lddb,
+                        dinfo_magma, batchCount, opts.queue );
+            }
+            else {
+                info = magma_zgesv_rbt_batched(
+                        N, nrhs,
+                        d_A_array, ldda,
+                        d_B_array, lddb,
+                        dinfo_magma, batchCount, opts.queue);
+            }
             gpu_time = magma_sync_wtime( opts.queue ) - gpu_time;
             gpu_perf = gflops / gpu_time;
             // check correctness of results throught "dinfo_magma" and correctness of argument throught "info"
@@ -119,7 +132,7 @@ int main(int argc, char **argv)
                 printf("magma_zgesv_nopiv_batched returned argument error %lld: %s.\n",
                        (long long) info, magma_strerror( info ));
             }
-            
+
             //=====================================================================
             // Residual
             //=====================================================================
@@ -145,7 +158,7 @@ int main(int argc, char **argv)
             }
             bool okay = (error < tol);
             status += ! okay;
-            
+
             /* ====================================================================
                Performs operation using LAPACK
                =================================================================== */
@@ -158,7 +171,7 @@ int main(int argc, char **argv)
                     printf("lapackf77_zgesv returned error %lld: %s.\n",
                            (long long) info, magma_strerror( info ));
                 }
-                
+
                 printf( "%10lld %5lld %5lld   %7.2f (%7.2f)   %7.2f (%7.2f)   %8.2e   %s\n",
                         (long long) batchCount, (long long) N, (long long) nrhs, cpu_perf, cpu_time, gpu_perf, gpu_time,
                         error, (okay ? "ok" : "failed"));
@@ -168,21 +181,21 @@ int main(int argc, char **argv)
                         (long long) batchCount, (long long) N, (long long) nrhs, gpu_perf, gpu_time,
                         error, (okay ? "ok" : "failed"));
             }
-            
+
             magma_free_cpu( h_A );
             magma_free_cpu( h_B );
             magma_free_cpu( h_X );
             magma_free_cpu( work );
             magma_free_cpu( ipiv );
             magma_free_cpu( cpu_info );
-            
+
             magma_free( dinfo_magma );
             magma_free( d_A );
             magma_free( d_B );
-            
+
             magma_free( d_A_array );
             magma_free( d_B_array );
-            
+
             fflush( stdout );
         }
         if ( opts.niter > 1 ) {
